@@ -3,7 +3,8 @@ use strict;
 use warnings;
 package Getopt::Lucid;
 # ABSTRACT: Clear, readable syntax for command line processing
-our $VERSION = '1.05'; # VERSION
+
+our $VERSION = '1.06';
 
 our @EXPORT_OK = qw(Switch Counter Param List Keypair);
 our %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
@@ -789,7 +790,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -797,7 +798,7 @@ Getopt::Lucid - Clear, readable syntax for command line processing
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -886,8 +887,6 @@ user control of precedence
 
 =back
 
-=for Pod::Coverage getopts
-
 =head1 USAGE
 
 =head2 Option Styles, Naming and "Strictness"
@@ -1358,6 +1357,8 @@ the accessor C<<< get_input_file >>> is ambiguous and may return either option,
 depending on which first satisfies a "fuzzy-matching" algorithm inside the
 accessor code.  Avoid identical names with mixed dash and underscore styles.
 
+=for Pod::Coverage getopts
+
 =head1 METHODS
 
 =head2 new()
@@ -1557,7 +1558,7 @@ existing test-file that illustrates the bug or desired feature.
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Getopt-Lucid>.
+at L<https://github.com/dagolden/getopt-lucid/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1567,7 +1568,7 @@ public review and contribution under the terms of the license.
 
 L<https://github.com/dagolden/getopt-lucid>
 
-  git clone git://github.com/dagolden/getopt-lucid.git
+  git clone https://github.com/dagolden/getopt-lucid.git
 
 =head1 AUTHOR
 
@@ -1575,15 +1576,21 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords David Golden Kevin McGrath Nova Patch Robert Bohne
+
 =over 4
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 Kevin McGrath <kmcgrath@cpan.org>
 
 =item *
 
-Nick Patch <patch@cpan.org>
+Nova Patch <patch@cpan.org>
 
 =item *
 
@@ -1593,7 +1600,7 @@ Robert Bohne <rbo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by David Golden.
+This software is Copyright (c) 2016 by David Golden.
 
 This is free software, licensed under:
 
