@@ -3,7 +3,8 @@ use strict;
 use warnings;
 package Getopt::Lucid::Exception;
 # ABSTRACT: Exception classes for Getopt::Lucid
-our $VERSION = '1.05'; # VERSION
+
+our $VERSION = '1.06';
 
 use Exporter;
 our @ISA = qw/Exporter Exception::Class::Base/;
@@ -45,7 +46,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -53,7 +54,7 @@ Getopt::Lucid::Exception - Exception classes for Getopt::Lucid
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for Pod::Coverage description
 throw_argv
@@ -64,27 +65,9 @@ throw_usage
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Kevin McGrath <kmcgrath@cpan.org>
-
-=item *
-
-Nick Patch <patch@cpan.org>
-
-=item *
-
-Robert Bohne <rbo@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by David Golden.
+This software is Copyright (c) 2016 by David Golden.
 
 This is free software, licensed under:
 
